Welcome to desmod
=================

Contents:

.. toctree::
   :maxdepth: 1

   api/index
   examples/index
   history

.. include:: ../README.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

